@@ -1,7 +1,7 @@
 #' Tidy Gapminder indicator data sheets stored in a folder
 #' using \code{\link{tidy_indice}}.
 #'
-#' @param dirpath Absolute path to folder containing indices
+#' @param dirpath Path to folder containing indices
 #'    data sheets.
 #' @param merge A boolean. If true, combines all indices data sheets
 #'    in one. Default: FALSE.
@@ -12,7 +12,7 @@
 #'
 #' @examples
 #'
-#' folder_path <- system.file("extdata/gapminder", package = "tidygapminder")
+#' folder_path <- system.file("extdata", package = "tidygapminder")
 #'
 #' tidy_bunch(folder_path)
 #'
@@ -20,25 +20,21 @@
 tidy_bunch <- function(dirpath = ".", merge = FALSE, ...) {
 
   # Data import ---------------------------------------
-
-  # Gapminder indices files souhl be in the same directory
-  # to be grouped under a same indice group.
-  message("We take in only csv or xlsx files")
-
-  file_list <- list.files(dirpath, pattern = "[.](csv|xlsx)$",
+  file_list <- list.files(dirpath,
+                          pattern = "[.](csv|xlsx)$",
                           full.names = TRUE)
 
-  # Tidy data ---------------------------------------
-
-  # To tidy all data once
+  # Tidy data -----------------------------------------
   df_list <- lapply(file_list, tidy_indice)
 
-  # Return result ------------------------------------
 
-  # Check if the user enable data frames to be merged into one
-  # or not.
+  # Return result -------------------------------------
+
+  # Check if the user enable data frames to be
+  # merged into one or not.
+
   if (merge == TRUE) {
-    df <- dplyr::bind_rows(df_list)
+    df <- Reduce(function(...) merge(..., all = T), df_list)
     df
   } else {
     df_list
